%define _libdir64 %{_prefix}/lib64

Name:		mpir
Version:	2.7.2
Release:	1
Summary:	A library for arbitrary precision arithmetic

Group:		System Environment/Libraries
License:	LGPLv3+
URL:		http://www.mpir.org/
Source0:	http://www.mpir.org/%{name}-%{version}.tar.bz2
# Sent upstream 4 Jan 2013.  Fix a broken test.
Patch0:		%{name}-%{version}-test.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires:	m4

%description
MPIR is an open source multiprecision integer library derived from
version 4.2.1 of the GMP (GNU Multi Precision) project.

The library is available as 32-bit and 64-bit.


%package  	devel
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description	devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".


%prep
%setup -q
%patch0
# convert Windows-style line endings to Unix-style
for f in doc/devel/* doc/isa_abi_headache; do
  sed 's/\r//' $f > $f.conv
  touch -r $f $f.conv
  mv -f $f.conv $f
done
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CONFIG_SHELL=/usr/bin/ksh
export CONFIG_ENV_ARGS=/usr/bin/ksh

export CC=xlc_r
export CXX=xlC_r

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --infodir=%{_infodir} \
    --enable-shared --disable-static \
    --enable-cxx \
    --enable-fft \
    ABI=aix64
make %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --infodir=%{_infodir} \
    --enable-shared --disable-static \
    --enable-cxx \
    --enable-fft \
    ABI=32
make %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

gzip --best ${RPM_BUILD_ROOT}%{_infodir}/*.info*
rm -f ${RPM_BUILD_ROOT}%{_infodir}/dir
mv doc/devel doc/html

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

(
  cd ${RPM_BUILD_ROOT}
  for dir in include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%post devel 
/sbin/install-info %{_infodir}/%{name}.info.gz %{_infodir}/dir || :


%postun devel
if [ $1 = 0 ] ; then
    /sbin/install-info --delete %{_infodir}/%{name}.info.gz %{_infodir}/dir || :
fi


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%doc 32bit/AUTHORS 32bit/COPYING 32bit/COPYING.LIB 32bit/NEWS 32bit/README
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%doc 32bit/doc/html 32bit/doc/isa_abi_headache
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_infodir}/*.info*
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 2.7.2-1
- updated to version 2.7.2

* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 2.7.1-1
- updated to version 2.7.1

* Fri Jan 01 2016 Michael Perzl <michael@perzl.org> - 2.7.0-1
- updated to version 2.7.0

* Mon Mar 25 2013 Michael Perzl <michael@perzl.org> - 2.6.0-1
- first version for AIX V5.1 and higher
